@@ -49,34 +49,29 @@
 
 package com.openexchange.file.storage.dropbox.osgi;
 
-import java.util.Dictionary;
-import java.util.Hashtable;
 import org.osgi.framework.BundleContext;
-import org.osgi.service.event.EventConstants;
-import org.osgi.service.event.EventHandler;
+import org.osgi.util.tracker.ServiceTrackerCustomizer;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.file.storage.FileStorageAccountManagerLookupService;
-import com.openexchange.file.storage.dropbox.DropboxConfiguration;
 import com.openexchange.file.storage.dropbox.DropboxServices;
-import com.openexchange.file.storage.oauth.OAuthFileStorageAccountEventHandler;
+import com.openexchange.file.storage.oauth.osgi.AbstractCloudStorageActivator;
 import com.openexchange.mime.MimeTypeMap;
 import com.openexchange.net.ssl.config.SSLConfigurationService;
 import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.OAuthService;
 import com.openexchange.oauth.OAuthServiceMetaData;
 import com.openexchange.oauth.access.OAuthAccessRegistryService;
-import com.openexchange.osgi.HousekeepingActivator;
-import com.openexchange.sessiond.SessiondEventConstants;
 import com.openexchange.sessiond.SessiondService;
 import com.openexchange.timer.TimerService;
+import com.openexchange.version.VersionService;
 
 /**
  * {@link DropboxActivator} - Activator for Dropbox bundle.
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public final class DropboxActivator extends HousekeepingActivator {
+public final class DropboxActivator extends AbstractCloudStorageActivator {
 
     /**
      * Initializes a new {@link DropboxActivator}.
@@ -87,34 +82,15 @@ public final class DropboxActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { FileStorageAccountManagerLookupService.class, ConfigurationService.class, SessiondService.class, MimeTypeMap.class, TimerService.class, OAuthService.class,
-            OAuthAccessRegistryService.class, SSLConfigurationService.class, ConfigViewFactory.class };
+        return new Class<?>[] { FileStorageAccountManagerLookupService.class, ConfigurationService.class, SessiondService.class, MimeTypeMap.class, 
+                                TimerService.class, OAuthService.class, OAuthAccessRegistryService.class, SSLConfigurationService.class, ConfigViewFactory.class,
+                                VersionService.class };
     }
 
     @Override
     protected void startBundle() throws Exception {
-        try {
-            DropboxServices.setServices(this);
-            /*
-             * Some initialization stuff
-             */
-            final BundleContext context = this.context;
-            DropboxConfiguration.getInstance().configure(getService(ConfigurationService.class));
-            /*
-             * Register tracker
-             */
-            track(OAuthServiceMetaData.class, new OAuthServiceMetaDataRegisterer(context));
-            openTrackers();
-            /*
-             * Register event handler
-             */
-            final Dictionary<String, Object> serviceProperties = new Hashtable<String, Object>(1);
-            serviceProperties.put(EventConstants.EVENT_TOPIC, SessiondEventConstants.TOPIC_LAST_SESSION);
-            registerService(EventHandler.class, new OAuthFileStorageAccountEventHandler(this, KnownApi.DROPBOX), serviceProperties);
-        } catch (final Exception e) {
-            org.slf4j.LoggerFactory.getLogger(DropboxActivator.class).error("", e);
-            throw e;
-        }
+        DropboxServices.setServices(this);
+        super.startBundle();
     }
 
     @Override
@@ -125,9 +101,8 @@ public final class DropboxActivator extends HousekeepingActivator {
     @Override
     protected void stopBundle() throws Exception {
         try {
-            // Clean-up
+            super.stopBundle();
             cleanUp();
-            // Clear service registry
             DropboxServices.setServices(null);
         } catch (final Exception e) {
             org.slf4j.LoggerFactory.getLogger(DropboxActivator.class).error("", e);
@@ -135,4 +110,23 @@ public final class DropboxActivator extends HousekeepingActivator {
         }
     }
 
+    /*
+     * (non-Javadoc)
+     * 
+     * @see com.openexchange.file.storage.oauth.osgi.AbstractCloudStorageActivator#getServiceRegisterer(org.osgi.framework.BundleContext)
+     */
+    @Override
+    protected ServiceTrackerCustomizer<OAuthServiceMetaData, OAuthServiceMetaData> getServiceRegisterer(BundleContext context) {
+        return new OAuthServiceMetaDataRegisterer(context, this);
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see com.openexchange.file.storage.oauth.osgi.AbstractCloudStorageActivator#getAPI()
+     */
+    @Override
+    protected KnownApi getAPI() {
+        return KnownApi.DROPBOX;
+    }
 }
